@@ -1,4 +1,5 @@
 # see: https://docs.python.org/3/library/socketserver.html
+import logging
 import socket
 import socketserver
 import traceback
@@ -33,6 +34,11 @@ class PsqlHandler(ABC, socketserver.StreamRequestHandler, socketserver.Threading
     def auth_handler_cls(self):
         raise Exception("Not implemented")
 
+    @property
+    @abstractmethod
+    def socket_timeout(self):
+        raise Exception("Not implemented")
+
     @property
     @abstractmethod
     def query_handler_cls(self):
@@ -42,12 +48,13 @@ class PsqlHandler(ABC, socketserver.StreamRequestHandler, socketserver.Threading
     def init_ssl(self, context: Context):
         raise Exception("Not implemented")
 
-
     def handle(self):
 
         print(f"First Connect")
+        logging.info(f"First connect")
 
-        self.request.settimeout(5)
+        # timeout causes the socket to become non blockgin
+        # self.request.settimeout(self.socket_timeout())
 
         input = ReadingIO(self.rfile)
         output = WritingIO(self.wfile)
@@ -98,16 +105,18 @@ class ThreadedTCPServer(socketserver.ThreadingMixIn, socketserver.TCPServer):
 
 
 def run(auth_handler_cls, query_handler_cls, extended_query_handler_cls, handler=None, host="", port=55432,
-        cert_file=None, key_file=None):
+        cert_file=None, key_file=None, socket_timeout=240):
     auth_1 = auth_handler_cls
     query_1 = query_handler_cls
     query_2 = extended_query_handler_cls
+    socket_timeout_1 = socket_timeout
 
     if not handler:
         class Handler(PsqlHandler):
             auth_handler_cls = auth_1
             query_handler_cls = query_1
             extended_query_handler_cls = query_2
+            socket_timeout = socket_timeout_1
 
             def init_ssl(self, context: Context):
                 context.key_file = key_file
