@@ -34,16 +34,19 @@ def move_state(context: Any, state: State) -> Tuple[Any, str]:
 
 
 processes = {
-    Names.READ_SSL_REQUEST: State(name=Names.READ_SSL_REQUEST, allowed={Names.WRITE_SSL_NO, Names.WRITE_SSL_YES}, fn=read_ssl_request),
-    Names.WRITE_SSL_NO: State(name=Names.READ_SSL_REQUEST, allowed={Names.READ_STARTUP_MESSAGE}, fn=write_ssl_resp_no),
-    Names.WRITE_SSL_YES: State(name=Names.READ_SSL_REQUEST, allowed={Names.READ_STARTUP_MESSAGE}, fn=write_ssl_resp_yes),
+    Names.READ_SSL_REQUEST: State(name=Names.READ_SSL_REQUEST,
+                                  allowed={Names.WRITE_SSL_NO, Names.WRITE_SSL_YES, Names.CLOSE}, fn=read_ssl_request),
+    Names.WRITE_SSL_NO: State(name=Names.READ_SSL_REQUEST, allowed={Names.READ_STARTUP_MESSAGE, Names.CLOSE},
+                              fn=write_ssl_resp_no),
+    Names.WRITE_SSL_YES: State(name=Names.READ_SSL_REQUEST, allowed={Names.READ_STARTUP_MESSAGE, Names.CLOSE},
+                               fn=write_ssl_resp_yes),
 
     Names.READ_STARTUP_MESSAGE: State(name=Names.READ_STARTUP_MESSAGE,
                                       allowed={Names.WRITE_PLAIN_TEXT_PASSWORD_REQUEST, Names.CLOSE,
                                                Names.READ_STARTUP_MESSAGE}, fn=read_startup_message),
 
     Names.WRITE_PLAIN_TEXT_PASSWORD_REQUEST: State(name=Names.WRITE_PLAIN_TEXT_PASSWORD_REQUEST,
-                                                   allowed={Names.READ_PLAIN_TEXT_PASSWORD},
+                                                   allowed={Names.READ_PLAIN_TEXT_PASSWORD, Names.CLOSE},
                                                    fn=write_plain_text_password_request),
 
     Names.READ_PLAIN_TEXT_PASSWORD: State(name=Names.READ_PLAIN_TEXT_PASSWORD,
@@ -51,7 +54,7 @@ processes = {
                                           fn=read_plain_text_password_request),
 
     Names.WRITE_AUTH_OK: State(name=Names.READ_PLAIN_TEXT_PASSWORD,
-                               allowed={Names.READY_FOR_QUERY},
+                               allowed={Names.READY_FOR_QUERY, Names.CLOSE},
                                fn=write_auth_ok),
 
     Names.READY_FOR_QUERY: State(name=Names.READY_FOR_QUERY,
