@@ -1,6 +1,7 @@
 from pandas import DataFrame
 
-from pypsql_api.wire.actions_types import Names, Context
+from pypsql_api.wire.actions_types import Names
+from pypsql_api.context import Context
 
 
 def process_simple_query(context: Context):
